//
// htmerge.cc
//
// Implementation of htmerge
//
// $Log$
//
#if RELEASE
static char RCSid[] = "$Id$";
#endif

#include "htmerge.h"


//
// This hash is used to keep track of all the document IDs which have to be
// discarded.
// The wordlist file contains the information on which docs need to go.
//
Dictionary	discard_list;

int			verbose = 0;
int			stats = 0;

void usage();
void reportError(char *msg);


//*****************************************************************************
// int main(int ac, char **av)
//
int main(int ac, char **av)
{
    int			do_words = 1;
    int			do_docs = 1;
    String		configfile = DEFAULT_CONFIG_FILE;
    int			c;
    extern int	optind;
    extern char	*optarg;

    while ((c = getopt(ac, av, "svc:dw")) != -1)
    {
	switch (c)
	{
	    case 'd':
		do_docs = 0;
		break;
	    case 'w':
		do_words = 0;
		break;
	    case 'c':
		configfile = optarg;
		break;
	    case 'v':
		verbose++;
		break;
	    case 's':
		stats++;
		break;
	    case '?':
		usage();
		break;
	}
    }

    config.Defaults(&defaults[0]);

    if (access(configfile, R_OK) < 0)
    {
	reportError(form("Unable to find configuration file '%s'",
			 configfile.get()));
    }
	
    config.Read(configfile);

    String	file1, file2;
    if (do_words)
    {
	file1 = config["word_list"];
	file2 = config["word_db"];
	mergeWords(file1, file2);
    }
    if (do_docs)
    {
	file1 = config["doc_db"];
	file2 = config["doc_index"];
	convertDocs(file1, file2);
    }
    return 0;
}


//*****************************************************************************
// void usage()
//   Display program usage information
//
void usage()
{
    cout << "usage: htmerge [-v][-d][-w][-c configfile]\n";
    cout << "Options:\n";
    cout << "\t-v\tVerbose mode.  This increases the verbosity of the\n";
    cout << "\t\tprogram.  Using more than 2 is probably only useful\n";
    cout << "\t\tfor debugging purposes.  The default verbose mode\n";
    cout << "\t\tgives a progress on what it is doing and where it is.\n\n";
    cout << "\t-d\tDo NOT merge the document database.\n\n";
    cout << "\t-w\tDo NOT merge the word database.\n\n";
    cout << "\t-c configfile\n";
    cout << "\t\tUse the specified configuration file instead on the\n";
    cout << "\t\tdefault.\n\n";
    exit(0);
}


//*****************************************************************************
// Report an error and die
//
void reportError(char *msg)
{
    cout << "htmerge: " << msg << "\n\n";
    exit(1);
}
